/**
 * DRAWING WITH LEAP MOTION
 * Uses tisane Boid library
 * https://github.com/nok/leap-motion-processing
 */




import tisane.geom.*;
import tisane.physics.*;
import de.voidplus.leapmotion.*;

LeapMotion leap;
boolean isConnect, updatePos;
PVector handPosition, indexPos;

Boid b;
float r = 3;

void setup() {
  size(720, 540);
  background(0, 0, 33);
  leap = new LeapMotion(this);
  Vec2D v1 = new Vec2D(width/2, height/2);
  b = new Boid(v1);
}


void draw() {
  //background(0, 0, 33);

  for (Hand hand : leap.getHands ()) {
    handPosition = hand.getPosition();
    //println(handPosition.z);

    Finger  fingerIndex = hand.getIndexFinger();
    indexPos = fingerIndex.getPosition();
    //println("Index finger pos: " +indexPos);
    PVector fingerVelocity   = fingerIndex.getVelocity();
    println("Finger velocity: " +fingerVelocity);

    if (fingerIndex.isExtended()) {
      isConnect = true;
    } else {
      isConnect = false;
      //updatePos(); // update position of boid on every new connect
      b.setLocation(indexPos.x, indexPos.y);
      println(isConnect);
    }
  }

  // only draw if we have a connection  
  if (isConnect) {
    // draw boid
    noStroke();
    float d = map(handPosition.z, 30, 60, 1, 15);
    ellipse(b.loc.x, b.loc.y, d, d);
    
    //Our boid follows another boid which is our hand position
    Boid t = new Boid(handPosition.x, handPosition.y);
    b.seek(t);
    b.setMaxForce(5.05f);
    b.setMaxSpeed(13.37f);
  }
  b.updateBoid();
}



void updatePos() {
  for (Hand hand : leap.getHands ()) {
    Finger  fingerIndex = hand.getIndexFinger();
    indexPos = fingerIndex.getPosition();
    //b.setLocation(indexPos.x, indexPos.y);
  }
}

void keyPressed() {
  setup();
}


void leapOnInit() {
  println("Leap Motion Init");
}
void leapOnConnect() {
  println("Leap Motion Connect");
}
void leapOnFrame() {
  // println("Leap Motion Frame");
}
void leapOnDisconnect() {
  println("Leap Motion Disconnect");
}
void leapOnExit() {
  println("Leap Motion Exit");
}